==> zio-aws-securityhub_2.13-5.17.116.1-sources.jar: zio/aws/securityhub/model/AwsEcsClusterClusterSettingsDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsEcsClusterClusterSettingsDetails(
    name: Option[NonEmptyString] = None,
    value: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails = {
    import AwsEcsClusterClusterSettingsDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
      .builder()
      .optionallyWith(
        name.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        value.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails
      .wrap(buildAwsValue())
}
object AwsEcsClusterClusterSettingsDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails =
      zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails(
        name.map(value => value),
        value.map(value => value)
      )
    def name: Option[NonEmptyString]
    def value: Option[NonEmptyString]
    def getName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("name", name)
    def getValue: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
  ) extends zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails.ReadOnly {
    override val name: Option[NonEmptyString] = scala
      .Option(impl.name())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val value: Option[NonEmptyString] = scala
      .Option(impl.value())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
  ): zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-7.21.15.10-sources.jar: zio/aws/securityhub/model/AwsEcsClusterClusterSettingsDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsEcsClusterClusterSettingsDetails(
    name: Optional[NonEmptyString] = Optional.Absent,
    value: Optional[NonEmptyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails = {
    import AwsEcsClusterClusterSettingsDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
      .builder()
      .optionallyWith(
        name.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        value.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails
      .wrap(buildAwsValue())
}
object AwsEcsClusterClusterSettingsDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails =
      zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails(
        name.map(value => value),
        value.map(value => value)
      )
    def name: Optional[NonEmptyString]
    def value: Optional[NonEmptyString]
    def getName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("name", name)
    def getValue: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
  ) extends zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails.ReadOnly {
    override val name: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val value: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsClusterClusterSettingsDetails
  ): zio.aws.securityhub.model.AwsEcsClusterClusterSettingsDetails.ReadOnly =
    new Wrapper(impl)
}
